@@ -1,22 +1,11 @@
-# Licensed to Elasticsearch B.V. under one or more contributor
-# license agreements. See the NOTICE file distributed with
-# this work for additional information regarding copyright
-# ownership. Elasticsearch B.V. licenses this file to you under
-# the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#   http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing,
-# software distributed under the License is distributed on an
-# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-# KIND, either express or implied.  See the License for the
-# specific language governing permissions and limitations
-# under the License.
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
 
-package Search::Elasticsearch::Client::6_0::Role::Scroll;
-$Search::Elasticsearch::Client::6_0::Role::Scroll::VERSION = '7.711001';
+package Search::Elasticsearch::Client::7_0::Role::Scroll;
+$Search::Elasticsearch::Client::7_0::Role::Scroll::VERSION = '7.30_1'; # TRIAL
+
+$Search::Elasticsearch::Client::7_0::Role::Scroll::VERSION = '7.301';
 use Moo::Role;
 requires 'finish';
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -24,7 +13,6 @@ use Devel::GlobalDestruction;
 use namespace::clean;
 has 'es' => ( is => 'ro', required => 1 );
 has 'scroll'        => ( is => 'ro' );
-has 'scroll_in_qs'  => ( is => 'ro' );
 has 'total'         => ( is => 'rwp' );
 has 'max_score'     => ( is => 'rwp' );
 has 'facets'        => ( is => 'rwp' );
@@ -47,12 +35,7 @@ sub scroll_request {
         if $self->_pid != $$;
 
     my %args = ( scroll => $self->scroll );
-    if ( $self->scroll_in_qs ) {
-        $args{scroll_id} = $self->_scroll_id;
-    }
-    else {
-        $args{body} = { scroll_id => $self->_scroll_id };
-    }
+    $args{body} = { scroll_id => $self->_scroll_id };
     $self->es->scroll(%args);
 }
 
@@ -66,7 +49,7 @@ sub DEMOLISH {
 
 1;
 
-# ABSTRACT: Provides common functionality to L<Search::Elasticsearch::Client::6_0::Scroll> and L<Search::Elasticsearch::Client::6_0::Async::Scroll>
+# ABSTRACT: Provides common functionality to L<Search::Elasticsearch::Client::7_0::Scroll> and L<Search::Elasticsearch::Client::7_0::Async::Scroll>
 
 __END__
 
@@ -76,11 +59,11 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::6_0::Role::Scroll - Provides common functionality to L<Search::Elasticsearch::Client::6_0::Scroll> and L<Search::Elasticsearch::Client::6_0::Async::Scroll>
+Search::Elasticsearch::Client::7_0::Role::Scroll - Provides common functionality to L<Search::Elasticsearch::Client::7_0::Scroll> and L<Search::Elasticsearch::Client::7_0::Async::Scroll>
 
 =head1 VERSION
 
-version 7.711001
+version 7.30_1
 
 =head1 AUTHOR
 
@@ -88,7 +71,7 @@ Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
